<!--
 * @Author: @liulin
 * @Date: 2022-06-22 14:23:11
 * @LastEditTime: 2023-03-27 17:45:09
-->
<template>
  <div class="box">
    <div style="display: flex">
      <el-form
        ref="searchForm"
        :model="searchForm"
        label-width="80px"
        class="searchTop"
      >
      <CascaderCompany
          :companyIds.sync="searchForm.companyIds"
          :roadSegmentId.sync="searchForm.roadSegmentId"
          :placeholder="'请选择公司名称'"
        />

        <el-select
          v-model="searchForm.roadSegmentId"
          placeholder="请选择路段"
          clearable
          filterable
        >
          <el-option
            v-for="item in roadData"
            :key="item.id"
            :label="item.name"
            :value="item.id"
          >
          </el-option>
        </el-select>
        <el-button size="small" @click="findinfo()" type="primary"
          >查询</el-button
        >
      </el-form>
    </div>
    <el-divider></el-divider>

    <ht-table
      @load="loadData"
      @row-dblclick="handleEdit"
      :data="data"
      :pageResult="pageResult"
      :selection="true"
      :show-custom-column="false"
      :show-export="false"
      ref="htTable"
      :default-sorter="[{direction: 'DESC',property: 'id_'}]"
    >
      <template v-slot:toolbar>
        <div style="display: flex">
          <el-button
            size="small"
            type="primary"
            @click="handleAdd"
            icon="el-icon-plus"
            >添加</el-button
          >
          <ht-delete-button
            :url="deleteUrl"
            :htTable="$refs.htTable"
            :method="'DELETE'"
            @after-delete="afterDelete"
            >删除</ht-delete-button
          >
        </div>
      </template>
      <template>
        <el-table-column type="expand">
          <template v-slot="{row}">
            <el-table :data="row.structureVehicles">
              <el-table-column
                label="车牌号"
                prop="carNumber"
                align="center"
                :show-overflow-tooltip="true"
              ></el-table-column>
              <el-table-column
                label="数量"
                prop="quantity"
                align="center"
                :show-overflow-tooltip="true"
              ></el-table-column>
              <el-table-column
                label="吨位"
                prop="type"
                align="center"
                :show-overflow-tooltip="true"
              ></el-table-column>
              <el-table-column
                label="车辆类型"
                prop="typeValue"
                align="center"
                :show-overflow-tooltip="true"
              ></el-table-column>
              <el-table-column
                label="性质"
                prop="natrue"
                align="center"
                :show-overflow-tooltip="true"
              ></el-table-column>
            </el-table>
          </template>
        </el-table-column>
        <ht-table-column
          prop="roadSegmentName"
          label="路段名称"
          :show-overflow-tooltip="true"
        />
        <ht-table-column
          prop="centPegK"
          label="主线桩号"
          :show-overflow-tooltip="true"
        />

        <ht-table-column
          prop="name"
          label="救援点名称"
          :show-overflow-tooltip="true"
        >
        </ht-table-column>
        <ht-table-column
          prop="locationMaintenanceArea"
          label="救援点所在位置"
          :show-overflow-tooltip="true"
          width="200"
        />

        <ht-table-column
          prop="lng"
          label="经度"
          :show-overflow-tooltip="true"
          :sortable="true"
        />
        <ht-table-column
          prop="lat"
          label="纬度"
          :show-overflow-tooltip="true"
        />
        <!-- <ht-table-column
          prop="companyName"
          label="所属公司名称"
          :show-overflow-tooltip="true"
        /> -->

        <ht-table-column
          prop="personnelQuantity"
          label="人员数量"
          :show-overflow-tooltip="true"
        >
        </ht-table-column>
      </template>
    </ht-table>

    <!-- 添加弹出框 -->
    <el-dialog
      :title="type === 'add' ? '【救援点】添加' : '【救援点】修改'"
      :visible.sync="dialogVisible"
      width="1000"
      :before-close="handleClose"
      :close-on-click-modal="false"
      top="8vh"
      v-loading.fullscreen="loading"
    >
      <el-form
        ref="form"
        v-form
        :model="form"
        :rules="rules"
        label-width="130px"
        v-if="dialogVisible"
      >
        <el-row>
          <el-col :span="12">
            <el-form-item label="所属路段" prop="roadSegmentId">
              <el-select
                v-model="form.roadSegmentId"
                placeholder="请选择路段"
                clearable
                style="width: 100%"
                @change="handleRoadSegmentChange"
              >
                <el-option
                  v-for="item in roadData"
                  :key="item.id"
                  :label="item.name"
                  :value="item.id"
                >
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="救援点所在位置" prop="expound">
              <el-input
                v-model="form.locationMaintenanceArea"
                placeholder="救援点所在位置"
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="12">
            <el-form-item label="人员数量" prop="personnelQuantity">
              <el-input
                v-model="form.personnelQuantity"
                placeholder="请输入人员数量"
              ></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="救援点名称" prop="name">
              <el-input
                v-model="form.name"
                placeholder="请输入救援点名称"
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="12">
            <el-form-item label="经度" prop="lng">
              <el-input v-model="form.lng" placeholder="请输入经度"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="纬度" prop="lat">
              <el-input v-model="form.lat" placeholder="请输入纬度"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="handleCancel">取 消</el-button>
        <el-button type="primary" @click="handleSubmit">保存</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import basicData from '@/api/basicData.js'
import CascaderCompany from '@/components/selector/CascaderCompany.vue'
export default {
  components: {
    CascaderCompany
  },
  data() {
    return {
      searchForm: {},
      roadData: [],
      companyOptions: [],
      data: [],
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      type: '',
      dialogVisible: false,
      loading: false,
      form: {},
      rules: {}
    }
  },
  created() {
    this.roadData = this.getroad()
    this.getCompany()
  },
  computed: {
    deleteUrl: function() {
      return window.context.yhxt + '/bizEmergencyRescueManagement/v1/'
    }
  },
  methods: {
    getCompany() {
      this.$http.post('${yhxt}/Company/v1/getCompany').then(res => {
        res.data.forEach(item => {
          this.companyOptions.push({
            id: item.id,
            name: item.name
          })
        })
      })
    },
    handleRoadSegmentChange(id) {
      this.roadData.forEach(item => {
        if (item.id == id) {
          this.form.roadSegmentName = item.name
          this.form.companyName = item.companyName
          this.form.companyId = item.companyId
        }
      })
    },
    handleCompanyChange(id) {
      this.companyOptions.forEach(item => {
        if (item.id == id) {
          this.form.companyName = item.name
        }
      })
    },
    handleSubmit() {
      this.$refs.form.validate(bool => {
        if (bool) {
          this.loading = true
          this.$http
            .post('${yhxt}/bizEmergencyRescueManagement/v1/', this.form)
            .then(res => {
              this.loading = false
              this.dialogVisible = false
              this.$refs.htTable.load() //重新获取数据
            })
        }
      })
    },
    handleClose(done) {
      done()
    },
    handleCancel() {
      this.dialogVisible = false
    },
    afterDelete() {
      this.$refs.htTable.load()
    },
    handleAdd() {
      this.form = {}
      this.dialogVisible = true
      this.type = 'add'
    },
    loadData(param, cb) {
      if (typeof this.topQuery !== 'undefined' && this.topQuery.length !== 0) {
        param.querys = typeof param.querys !== 'undefined' ? param.querys : []
        this.topQuery.forEach(item => {
          param.querys.push(item)
        })
        param.querys = this.uniqueFunc(param.querys, 'property')
      }

      this.$http
        .post('${yhxt}/bizEmergencyRescueManagement/v1/query', param)
        .then(res => {
          let response = res.data
          this.data = response.rows
          this.pageResult = {
            page: response.page,
            pageSize: response.pageSize,
            total: response.total
          }
        })
        .finally(() => {
          if (cb) {
            if (
              Object.keys(this.$route.params).length !== 0 &&
              Object.keys(this.$route.params.value).length !== 0 &&
              this.$route.params.value.roadSegmentId && 
              !this.isFindinfo
            ) {
              this.searchForm = {
                roadSegmentId: this.$route.params.value.roadSegmentId
              }
              this.isFindinfo = true
              this.findinfo()
            }
            cb()
          }
        })
    },
    handleEdit(data) {
      this.dialogVisible = true
      this.type = 'edit'
      this.form = {...data}
    },
    findinfo() {
      let query = []
      let search = {
        company_id_: this.searchForm.companyIds,
        road_segment_id_: this.searchForm.roadSegmentId
      }
      for (let i in search) {
        if (search[i]) {
          if (i == 'company_id_') {
            query.push({
              group: 'companyIds',
              operation: 'IN',
              parentGroup: '',
              property: 'COMPANY_ID_',
              relation: 'AND',
              value: search[i]
            })
          } else {
            query.push({
              group: 'advance',
              operation: 'EQUAL',
              property: i,
              relation: 'AND',
              value: search[i]
            })
          }
        }
      }
      let data = {
        pageBean: {
          page: 1,
          pageSize: 20,
          showTotal: true
        },
        querys: query
      }
      this.topQuery = query
      this.$http
        .post('${yhxt}/bizEmergencyRescueManagement/v1/query', data)
        .then(res => {
          let response = res.data
          this.data = response.rows
          this.pageResult = {
            page: response.page,
            pageSize: response.pageSize,
            total: response.total
          }
        })
    },
    uniqueFunc(arr, uniId) {
      const res = new Map()
      return arr.filter(
        item => !res.has(item[uniId]) && res.set(item[uniId], 1)
      )
    },
    getroad() {
      let arr = []
      basicData.getRoadManagement().then(res => {
        res.rows.forEach(item => {
          arr.push({
            name: item.name,
            id: item.id,
            companyName: item.companyName,
            companyId: item.companyId
          })
        })
      })
      return arr
    }
  }
}
</script>
<style lang="scss" scoped>
.box {
  padding: 10px;
}
/deep/ .el-dialog__header {
  border-right: 1px solid #103c5d;
}
/deep/ .el-dialog .el-dialog__body {
  flex: 1;
  overflow: auto;
}
/deep/.el-divider--horizontal {
  height: 10px;
  margin: 0 !important;
  position: absolute;
  left: 0;
}
/deep/.ht-table-panel {
  padding-top: 20px;
  height: calc(100% - 7%);
  overflow: hidden;
  background: #fff;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}
/deep/.ht-quick__search {
  margin-bottom: 10px;
}
/deep/.ht-table {
  height: calc(100% - 4vw) !important;
  max-height: calc(100% - 4vw) !important;
}
/deep/.pagination-panel {
  padding: 10px 0 0 0;
}
.searchTop > div {
  max-width: 200px;
}
/deep/ .el-table__expand-icon > .el-icon {
  color: #fff;
}
/deep/ .el-table__expanded-cell {
  background-color: #103c5d;
}

/deep/ .el-table thead tr th {
  background-color: #114066 !important;
}
</style>
